@@ -3,10 +3,7 @@
 #' @description Print method for rd_pat object
 #'
 #' @param x Random patterns.
-#' @param calc_energy If TRUE energy is calculated.
 #' @param digits Number of decimal places (round).
-#' @param weights Weights used to calculate energy. The first number refers to Gest(r),
-#' the second number to pcf(r).
 #' @param ... Arguments passed to cat
 #'
 #' @details
@@ -34,18 +31,13 @@
 
 #' @export
 print.rd_pat <- function(x,
-                         calc_energy = TRUE,
                          digits = 4,
-                         weights = c(0.5, 0.5),
                          ...) {
 
   # set length observed pattern to 0 and
   # return warning that energy can't be calculated
   if (!spatstat::is.ppp(x$observed)) {
 
-    warning("Energy can not be calculated without observed pattern.",
-            call. = FALSE)
-
     number_patterns_obs <- 0
 
     includes_observed <- "NA"
@@ -62,24 +54,6 @@ print.rd_pat <- function(x,
   # get number of randomized patterns plus observed pattern
   number_patterns <- length(x$randomized) + number_patterns_obs
 
-  # calculate energy
-  if (calc_energy) {
-
-  # try to calculate energy
-  energy <- tryCatch(expr = round(calculate_energy(x,
-                                                   weights = weights,
-                                                   return_mean = TRUE,
-                                                   verbose = FALSE),
-                                  digits = digits),
-                     error = function(e) NA)
-  }
-
-  # not calculate energy
-  else {
-
-    energy <- NA
-  }
-
   # calculate mean iterations
   mean_iterations <- round(mean(unlist(x$iterations)),
                            digits = digits)
@@ -90,13 +64,12 @@ print.rd_pat <- function(x,
 
   if (!any(is.na(stop_criterion))) {
 
-    stop_criterion <- paste0(paste0(names(stop_criterion), ":", stop_criterion),
+    stop_criterion <- paste0(paste0(names(stop_criterion), "=", stop_criterion),
                              collapse = " ")
   }
 
   # print result
   cat(paste0("No. of pattern: ", number_patterns, "\n",
-             "Mean energy: ", energy, "\n",
              "Method: ", x$method, "\n",
              "Observed pattern: ", includes_observed, "\n",
              "Iterations (mean): ", mean_iterations, "\n",
