@@ -1,4 +1,4 @@
-testthat::context("Fit point process")
+testthat::context("test-fit_point_process")
 
 # normal
 pattern_random <- shar::fit_point_process(pattern = shar::species_b,
@@ -28,42 +28,43 @@ pattern_random_simple <- shar::fit_point_process(pattern = shar::species_a,
 
 testthat::test_that("Output is a long as n_random for fit_point_process", {
 
-  testthat::expect_length(pattern_random,
-                          n = 4)
+  testthat::expect_length(pattern_random$randomized,
+                          n = 3)
 
-  testthat::expect_length(pattern_random_cluster,
-                          n = 4)
+  testthat::expect_length(pattern_random_cluster$randomized,
+                          n = 3)
 })
 
 testthat::test_that("Output includes randomizations and original pattern for fit_point_process", {
 
-  testthat::expect_named(pattern_random,
-                         expected = c(paste0("randomized_", 1:3), "observed"))
+  testthat::expect_named(pattern_random$randomized,
+                         expected = paste0("randomized_", 1:3))
 
-  testthat::expect_equal(pattern_random[[4]],
+  testthat::expect_equal(pattern_random$observed,
                          expected = spatstat::unmark(shar::species_b))
 
-  testthat::expect_named(pattern_random_cluster,
-                         expected = c(paste0("randomized_", 1:3), "observed"))
+  testthat::expect_named(pattern_random_cluster$randomized,
+                         expected = paste0("randomized_", 1:3))
 
-  testthat::expect_equal(pattern_random_cluster[[4]],
+  testthat::expect_equal(pattern_random_cluster$observed,
                          expected = spatstat::unmark(shar::species_b))
 })
 
 testthat::test_that("Fitted patterns have same number of points for cluster process", {
 
-  testthat::expect_true(all(vapply(pattern_random,
+  testthat::expect_true(all(vapply(pattern_random$randomized,
                                    FUN.VALUE = logical(1),
                                    function(x) x$n == shar::species_b$n)))
 
-  testthat::expect_true(all(vapply(pattern_random_cluster,
+  testthat::expect_true(all(vapply(pattern_random_cluster$randomized,
                                    FUN.VALUE = logical(1),
                                    function(x) x$n == shar::species_b$n)))
 })
 
 testthat::test_that("Input pattern can not be returned for fit_point_process", {
 
-  testthat::expect_false(any(shar::species_a %in% pattern_random_ni))
+  testthat::expect_equal(object = pattern_random_ni$observed,
+                         expected = "NA")
 })
 
 testthat::test_that("simplify works for fit_point_process", {
